@@ -218,11 +218,7 @@ class FacileToolkit2:
         self.set_selenium_library()
         try:
             self.sl.log_location()
-            self._wait_until(
-                lambda: url in self.sl.get_location() and self.sl.execute_javascript(JS_DOM_LOADED),
-                "Page %s didn't load correctly in <TIMEOUT>." % url,
-                timeout, error
-            )
+            self.sl.wait_until_location_contains(url, timeout)
             is_jquery_present = BuiltIn().run_keyword_and_return_status('wait_for_condition', 'if(typeof(jQuery) == "function") {return true;} return false;', "1s")
             if is_jquery_present:
                 self.wait_ajax_optional()
@@ -693,6 +689,10 @@ class FacileToolkit2:
     def focus_jquery(self, locator):
         self.execute_jquery_method_on_webelement(locator, "focus();")
 
+    @keyword
+    def change_jquery(self, locator):
+        self.execute_jquery_method_on_webelement(locator, "change();")
+
     @keyword
     def blur_jquery(self, locator):
         try:
